package com.szyd.setting;


import android.app.AlertDialog;
import android.os.Build;
import android.os.Bundle;
import android.os.Environment;
import android.os.SystemClock;
import android.support.annotation.NonNull;
import android.support.annotation.Nullable;
import android.support.v4.app.Fragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.ListView;
import android.widget.TextView;

import com.szyd.uhfdemo.BuildConfig;
import com.szyd.uhfdemo.MyApp;
import com.szyd.uhfdemo.R;
import com.szyd.util.MLog;
import com.szyd.util.MUtil;
import com.szyd.util.ThreadUtil;

import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.List;


public class AboutHelpFragment extends Fragment implements View.OnClickListener {

    private TextView be_seleted_ver;
    private TextView sw_ver;
    private TextView hw_ver;
    private TextView fm_ver;
    private Button fm_update;

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        return inflater.inflate(R.layout.fragment_about_help, container, false);
    }

    @Override
    public void onViewCreated(@NonNull View v, @Nullable Bundle savedInstanceState) {
        super.onViewCreated(v, savedInstanceState);
        sw_ver = v.findViewById(R.id.sw_ver);
        hw_ver = v.findViewById(R.id.hw_ver);
        fm_ver = v.findViewById(R.id.fm_ver);
        be_seleted_ver = v.findViewById(R.id.be_seleted_ver);
        fm_update = v.findViewById(R.id.fm_update);
        fm_update.setOnClickListener(this);
        v.findViewById(R.id.bin_file).setOnClickListener(this);
        updateUI();
    }

    private void updateUI() {
        sw_ver.setText(getString(R.string.software_ver) + BuildConfig.VERSION_NAME);
        hw_ver.setText(getString(R.string.hardware_ver) + getHardware());
        fm_ver.setText(getString(R.string.firemware_ver) + getFirmware());
    }

    // 获取固件版本
    private String getFirmware() {
        StringBuilder fw = new StringBuilder(MyApp.getMyApp().getIdataLib().firmwareVerGet());
        //  return fw.insert(2, ".").insert(5, ".").toString();
        String fwVer = fw.toString();
        if (fwVer.contains("-")) {
            return "";
        }
        return getDesignatedDecimalData(fwVer);
    }

    //获取硬件版本
    private String getHardware() {
        StringBuilder hw = new StringBuilder(MyApp.getMyApp().getIdataLib().hardwareVerGet());
        //return hw.insert(2, ".").insert(5, ".").toString();
        String hwVer = hw.toString();
        MLog.e("hwVer = " + hwVer);
        if (hwVer.contains("-")) {
            MUtil.show(R.string.firmware_getinfo_failed);
            return "";
        }
        return getDesignatedDecimalData(hwVer);
    }

    //机器内置sd卡的根目录(具体的目录地址可自行修改拼接处理)
    private String sdcardpath = Environment.getExternalStorageDirectory().getAbsolutePath();
    // private String binPath = "UM7V1.2.83.bin"; //具体需要更新的固件名称

    //更新固件
    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.fm_update:
                MUtil.showProgressDialog(getString(R.string.firmware_update_wait), getActivity());
                ThreadUtil.getInstance().getExService().execute(new Runnable() {
                    @Override
                    public void run() {
                        //value为固件更新状态，true成功，false失败，更新大约40s到60s左右，推荐使用子线程更新固件写法
                        final boolean value = MyApp.getMyApp().getIdataLib().updateFirmware(sdcardpath + File.separator + currentBinName, currentBinName);
                        //更新完毕切换到主线程操作ui通知(android里面ui更新只建议在主线程操作)
                        getActivity().runOnUiThread(new Runnable() {
                            @Override
                            public void run() {
                                if (value) {
                                    SystemClock.sleep(1000);
                                    updateUI();
                                }
                                MUtil.cancleDialog();
                                MUtil.show(value ? R.string.firmware_update_success : R.string.firmware_update_failed);
                                fm_update.setEnabled(false);
                            }
                        });
                    }
                });
                break;
            case R.id.bin_file:
                showDiaog();
                break;
        }
    }

    //底层固件版本进制转换拼接
    private String getDesignatedDecimalData(String hexString) {
        StringBuilder version = new StringBuilder();
        int n = 0;
        for (int i = 0; i < 3; i++) {
            int vals = Integer.parseInt(hexString.substring(n, n + 2), 16);
            String val = i < 2 ? vals + "." : vals + "";
            version.append(val);
            n += 2;
        }
        return version.toString();
    }

    //sd卡根目录.bin文件的获取
    private List<String> getBinFileName() {
        List<String> ar = new ArrayList<>();
        File file = new File(sdcardpath);
        MLog.e("sdcardpath = " + sdcardpath);
        File allFiles[] = file.listFiles();
        MLog.e(" size = " + (allFiles == null));
        if (allFiles != null) {
            for (File allFile : allFiles) {
                String mfileName = allFile.getName();
                MLog.e(" currentFile = " + mfileName);
                if (mfileName.endsWith(".bin")) {
                    ar.add(mfileName);
                }
            }
        }
        return ar;
    }

    private AlertDialog adialog;
    private String currentBinName;

    private void showDiaog() {
        if (adialog == null) {
            adialog = new AlertDialog.Builder(getActivity()).create();
            adialog.setTitle(R.string.select_bin_file);
            List<String> allBinFile = getBinFileName();
            ListView showBin = new ListView(getActivity());
            showBin.setOnItemClickListener(new AdapterView.OnItemClickListener() {
                @Override
                public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
                    String fvVer = ((TextView) view.findViewById(android.R.id.text1)).getText().toString();
                    be_seleted_ver.setText(getString(R.string.select_firemaware_ver) + fvVer);
                    currentBinName = fvVer;
                    cancleDialog();
                    fm_update.setEnabled(true);
                }
            });
            showBin.setAdapter(new ArrayAdapter<>(getContext(), android.R.layout.simple_list_item_1, allBinFile));
            adialog.setView(showBin);
            //  adialog.create();
            adialog.show();
        } else {
            adialog.show();
        }
    }

    private void cancleDialog() {
        if (adialog != null) {
            adialog.cancel();
            adialog = null;
        }
    }


}
